bisect

Function bisect 

pub fn bisect(
    clause_id: &ClauseId,
    _specs: &SpecGraph,
    runner: &dyn Runner,
    options: &BisectOptions,
) -> Result<BisectResult>
Binary search through git history to find the commit that broke a clause.

Always restores the working tree to its original state after completion.